==> vividict-0.1.0.tar.gz: vividict-0.1.0/README.md <==
# Home of the ViviDict Package
This package contains the Vividict class which can be used to create nested dictionaries in python.
### By: Charbel Marche
---
### Meta Data
* Title:    ViviDict Package
* Author:   Charbel Antoine Marche
* Date:     July 10, 2024 
* Language: Python
* Comment:  This package contains a simple vividict class that is adapted from various stackoverflow answers.
            It enables the creation of nested dictionaries, which is necessary across many stockscrapers projects.  
* URL:      https://github.com/charbelmarche33/DS5100-finalproject-qdy4zt
---
## Table of Contents
* [Installation](#installation)
* [Usage](#Usage)
* [More From Us](#Usage)

## Installation
You can install this package locally using the following command in your terminal.
s
```bash
pip install git+https://github.com/StockScrapers/vividict
```

This should install the latest vividict version to your environment.

## Usage
Once the package is installed, you can import the Vividict class into your python project as such:
```python
from vividict import Vividict
```

Then you can initialize your vividict object with the below code.
```python
vivi = Vividict()
```

From then on out you can use the 'vivi' variable (or the respectively named variable) to create a nested dictionary.
```python
vivi[outerkey][innerkey] = value
```

## More From Us
* Website: https://stockscrapers.com
* Financial Statement API: https://rapidapi.com/charbelmarche33-m9pHgx2tG/api/stock-financial-statement-retriever-from-sec

==> vividict-0.1.1.tar.gz: vividict-0.1.1/README.md <==
# Home of the ViviDict Package
This package contains the Vividict class which can be used to create nested dictionaries in python.
### By: Charbel Marche
---
### Meta Data
* Title:    ViviDict Package
* Author:   Charbel Antoine Marche
* Date:     July 10, 2024 
* Language: Python
* Comment:  This package contains a simple vividict class that is adapted from various stackoverflow answers.
            It enables the creation of nested dictionaries, which is necessary across many stockscrapers projects.  
* URL:      https://github.com/StockScrapers/vividict
---
## Table of Contents
* [Installation](#installation)
* [Usage](#usage)
* [More From Us](#more-from-us)

## Installation
You can install this package locally using the following command in your terminal.
s
```bash
pip install vividict
```

This should install the latest vividict version to your environment.

## Usage
Once the package is installed, you can import the Vividict class into your python project as such:
```python
from vividict import Vividict
```

Then you can initialize your vividict object with the below code.
```python
vivi = Vividict()
```

From then on out you can use the 'vivi' variable (or the respectively named variable) to create a nested dictionary.
```python
vivi[outerkey][innerkey] = value
```

## More From Us
* Website: https://stockscrapers.com
* Financial Statement API: https://rapidapi.com/charbelmarche33-m9pHgx2tG/api/stock-financial-statement-retriever-from-sec
* On PyPi: https://pypi.org/user/charbelmarche33/
